==> aws-java-sdk-waf-1.11.69-sources.jar: com/amazonaws/services/waf/model/waf_regional/transform/GetSampledRequestsRequestMarshaller.java <==
/*
 * Copyright 2011-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */
package com.amazonaws.services.waf.model.waf_regional.transform;

import java.io.ByteArrayInputStream;
import java.util.Collections;
import java.util.Map;
import java.util.List;
import java.util.regex.Pattern;

import com.amazonaws.SdkClientException;
import com.amazonaws.Request;
import com.amazonaws.DefaultRequest;
import com.amazonaws.http.HttpMethodName;
import com.amazonaws.services.waf.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.protocol.json.*;

/**
 * GetSampledRequestsRequest Marshaller
 */
public class GetSampledRequestsRequestMarshaller implements Marshaller<Request<GetSampledRequestsRequest>, GetSampledRequestsRequest> {

    private final SdkJsonProtocolFactory protocolFactory;

    public GetSampledRequestsRequestMarshaller(SdkJsonProtocolFactory protocolFactory) {
        this.protocolFactory = protocolFactory;
    }

    public Request<GetSampledRequestsRequest> marshall(GetSampledRequestsRequest getSampledRequestsRequest) {

        if (getSampledRequestsRequest == null) {
            throw new SdkClientException("Invalid argument passed to marshall(...)");
        }

        Request<GetSampledRequestsRequest> request = new DefaultRequest<GetSampledRequestsRequest>(getSampledRequestsRequest, "AWSWAFRegional");
        request.addHeader("X-Amz-Target", "AWSWAF_Regional_20161128.GetSampledRequests");

        request.setHttpMethod(HttpMethodName.POST);

        request.setResourcePath("");

        try {
            final StructuredJsonGenerator jsonGenerator = protocolFactory.createGenerator();

            jsonGenerator.writeStartObject();

            if (getSampledRequestsRequest.getWebAclId() != null) {
                jsonGenerator.writeFieldName("WebAclId").writeValue(getSampledRequestsRequest.getWebAclId());
            }
            if (getSampledRequestsRequest.getRuleId() != null) {
                jsonGenerator.writeFieldName("RuleId").writeValue(getSampledRequestsRequest.getRuleId());
            }
            if (getSampledRequestsRequest.getTimeWindow() != null) {
                jsonGenerator.writeFieldName("TimeWindow");
                TimeWindowJsonMarshaller.getInstance().marshall(getSampledRequestsRequest.getTimeWindow(), jsonGenerator);
            }
            if (getSampledRequestsRequest.getMaxItems() != null) {
                jsonGenerator.writeFieldName("MaxItems").writeValue(getSampledRequestsRequest.getMaxItems());
            }

            jsonGenerator.writeEndObject();

            byte[] content = jsonGenerator.getBytes();
            request.setContent(new ByteArrayInputStream(content));
            request.addHeader("Content-Length", Integer.toString(content.length));
            request.addHeader("Content-Type", protocolFactory.getContentType());
        } catch (Throwable t) {
            throw new SdkClientException("Unable to marshall request to JSON: " + t.getMessage(), t);
        }

        return request;
    }

}

==> aws-java-sdk-waf-1.11.75-sources.jar: com/amazonaws/services/waf/model/waf_regional/transform/GetSampledRequestsRequestMarshaller.java <==
/*
 * Copyright 2011-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */
package com.amazonaws.services.waf.model.waf_regional.transform;

import java.io.ByteArrayInputStream;
import java.util.Collections;
import java.util.Map;
import java.util.List;
import java.util.regex.Pattern;

import com.amazonaws.SdkClientException;
import com.amazonaws.Request;
import com.amazonaws.DefaultRequest;
import com.amazonaws.http.HttpMethodName;
import com.amazonaws.services.waf.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.protocol.json.*;

/**
 * GetSampledRequestsRequest Marshaller
 */
public class GetSampledRequestsRequestMarshaller implements Marshaller<Request<GetSampledRequestsRequest>, GetSampledRequestsRequest> {

    private final SdkJsonMarshallerFactory protocolFactory;

    public GetSampledRequestsRequestMarshaller(SdkJsonMarshallerFactory protocolFactory) {
        this.protocolFactory = protocolFactory;
    }

    public Request<GetSampledRequestsRequest> marshall(GetSampledRequestsRequest getSampledRequestsRequest) {

        if (getSampledRequestsRequest == null) {
            throw new SdkClientException("Invalid argument passed to marshall(...)");
        }

        Request<GetSampledRequestsRequest> request = new DefaultRequest<GetSampledRequestsRequest>(getSampledRequestsRequest, "AWSWAFRegional");
        request.addHeader("X-Amz-Target", "AWSWAF_Regional_20161128.GetSampledRequests");

        request.setHttpMethod(HttpMethodName.POST);

        request.setResourcePath("");

        try {
            final StructuredJsonGenerator jsonGenerator = protocolFactory.createGenerator();

            jsonGenerator.writeStartObject();

            if (getSampledRequestsRequest.getWebAclId() != null) {
                jsonGenerator.writeFieldName("WebAclId").writeValue(getSampledRequestsRequest.getWebAclId());
            }
            if (getSampledRequestsRequest.getRuleId() != null) {
                jsonGenerator.writeFieldName("RuleId").writeValue(getSampledRequestsRequest.getRuleId());
            }
            if (getSampledRequestsRequest.getTimeWindow() != null) {
                jsonGenerator.writeFieldName("TimeWindow");
                TimeWindowJsonMarshaller.getInstance().marshall(getSampledRequestsRequest.getTimeWindow(), jsonGenerator);
            }
            if (getSampledRequestsRequest.getMaxItems() != null) {
                jsonGenerator.writeFieldName("MaxItems").writeValue(getSampledRequestsRequest.getMaxItems());
            }

            jsonGenerator.writeEndObject();

            byte[] content = jsonGenerator.getBytes();
            request.setContent(new ByteArrayInputStream(content));
            request.addHeader("Content-Length", Integer.toString(content.length));
            request.addHeader("Content-Type", protocolFactory.getContentType());
        } catch (Throwable t) {
            throw new SdkClientException("Unable to marshall request to JSON: " + t.getMessage(), t);
        }

        return request;
    }

}
